@@ -59,7 +59,12 @@ import os
 import re
 import shlex
 import shutil
-import simplejson
+
+try:
+    import json as simplejson
+except:
+    import simplejson
+
 import string
 import subprocess
 import sys
@@ -69,12 +74,14 @@ import ximport
 
 #Global Variables
 showMakeData = 0
-progVersion="0.4.7"
+progVersion="0.4.10"
 
 class Builder():
     def __init__(self, makeCommand=["make","-f","client.mk","build"] , shellCacheDir=os.path.join(os.path.expanduser("~"),
                  "moz-commitbuilder-cache"), cores=1, repoURL="http://hg.mozilla.org/mozilla-central",clean=False,
-                 mozconf=None, tryhost=None, tryport=None, remote=False, tryPusher=False, testBinaries=False):
+                 mozconf=None, tryhost=None, tryport=None, remote=False, tryPusher=False,
+                 testBinaries=False, deleteTrunk=False):
+
         #Set variables that we need
         self.makeCommand = makeCommand
         self.shellCacheDir = shellCacheDir
@@ -93,6 +100,17 @@ class Builder():
         self.remote = remote
         self.tryPusher = tryPusher
 
+        # Cleanup flag
+        if deleteTrunk:
+            print "Performing cleanup..."
+            try:
+                shutil.rmtree(self.shellCacheDir)
+                print "Cleaned up!"
+                quit()
+            except:
+                quit()
+
+
         #Create directories we need
         if not os.path.exists(shellCacheDir):
             os.mkdir(shellCacheDir)
@@ -101,6 +119,9 @@ class Builder():
         if not os.path.exists(self.binaryDir):
             os.mkdir(self.binaryDir)
 
+
+        #Gets or updates our cached repo for building
+
         #Sanity check: make sure hg is installed on the system, otherwise do not proceed!
         try:
             testhgInstall = subprocess.Popen(["hg","--version"],stdout=subprocess.PIPE)
@@ -346,13 +367,13 @@ class Builder():
             #now nightly is installed in
             if sys.platform == "darwin":
                 binary_path = os.path.join(self.testDir,"Nightly.app")
-                runner = FirefoxRunner(binary=os.path.join(binary_path,"Contents","MacOS")+"/firefox-bin")
+                runner = FirefoxRunner.create(binary=os.path.join(binary_path,"Contents","MacOS")+"/firefox-bin")
             elif sys.platform == "linux2":
                 binary_path = os.path.join(self.testDir,"firefox")
-                runner = FirefoxRunner(binary=binary_path)
+                runner = FirefoxRunner.create(binary=binary_path)
             elif sys.platform == "win32" or sys.platform == "cygwin":
                 binary_path = os.path.join(self.testDir,"firefox.exe")
-                runner = FirefoxRunner(binary=binary_path)
+                runner = FirefoxRunner.create(binary=binary_path)
             else:
                 print "Your platform is not currently supported."
                 quit()
@@ -458,15 +479,15 @@ class Builder():
     def run(self):
         #Run the built binary if it exists. ONLY WORKS IF BUILD WAS CALLED!
         if sys.platform == "darwin":
-            runner = FirefoxRunner(binary=os.path.join(self.shellCacheDir,"mozbuild-trunk","obj-ff-dbg","dist","NightlyDebug.app","Contents","MacOS")+"/firefox-bin")
+            runner = FirefoxRunner.create(binary=os.path.join(self.shellCacheDir,"mozbuild-trunk","obj-ff-dbg","dist","NightlyDebug.app","Contents","MacOS")+"/firefox-bin")
             runner.start()
             runner.wait()
         elif sys.platform == "linux2":
-            runner = FirefoxRunner(binary=os.path.join(self.shellCacheDir,"mozbuild-trunk","obj-ff-dbg","dist","bin") + "/firefox")
+            runner = FirefoxRunner.create(binary=os.path.join(self.shellCacheDir,"mozbuild-trunk","obj-ff-dbg","dist","bin") + "/firefox")
             runner.start()
             runner.wait()
         elif sys.platform == "win32" or sys.platform == "cygwin":
-            runner = FirefoxRunner(binary=os.path.join(self.shellCacheDir,"mozbuild-trunk","obj-ff-dbg","dist","bin") + "/firefox.exe")
+            runner = FirefoxRunner.create(binary=os.path.join(self.shellCacheDir,"mozbuild-trunk","obj-ff-dbg","dist","bin") + "/firefox.exe")
             runner.start()
             runner.wait()
         else:
@@ -552,6 +573,9 @@ def cli():
     group1.add_option("-f", "--freshtrunk", action = "store_true", dest="makeClean", default=False,
                                         help="Delete old trunk and use a fresh one")
 
+    group1.add_option("-d", "--deletetrunk", action = "store_true", dest="deleteTrunk", default=False,
+                                        help="Cleanup Flag: deletes the temp directory / trunk generated. Do not use with other flags, this is just for convenient cleanup.")
+
 
     group2 = OptionGroup(parser, "Bisector Options",
                                         "These are options for bisecting on changesets. Dates are retrieved from pushlog " \
@@ -627,7 +651,7 @@ def cli():
     (options, args_for_condition) = parser.parse_args()
 
     # If a user only wants to make clean or has supplied no options:
-    if (not options.good or not options.bad) and not options.single:
+    if (not options.good or not options.bad) and not options.single and not options.deleteTrunk:
         if options.makeClean:
             #Make a clean trunk and quit.
             commitBuilder = Builder(clean=options.makeClean)
@@ -641,7 +665,8 @@ def cli():
 
     # Set up a trunk for either bisection or build.
     mozConfiguration = options.mozconf
-    commitBuilder = Builder(clean=options.makeClean, mozconf=mozConfiguration, tryhost=options.tryhost, tryport=options.tryport, remote=options.remote, tryPusher=options.trypusher)
+    commitBuilder = Builder(clean=options.makeClean, mozconf=mozConfiguration, tryhost=options.tryhost, tryport=options.tryport, remote=options.remote, tryPusher=options.trypusher, deleteTrunk=options.deleteTrunk)
+
     if options.cores:
         commitBuilder.cores = options.cores
         commitBuilder.mozconfigure()
